
/*****************************************************************************
 *                                                                           *
 * This FILE mx12p_lib.h                                                     *
 * is part of the MX12P library.  It is based on code copyright 1996 and     *
 * 1998 by Adimec Advanced Image Systems B.V.  Unix conversion copyright     *
 * 1999 and 2000 by Gregory L. Kreider.  All rights reserved.  See           *
 * mx12p_lib.c for distribution terms.                                       *
 *                                                                           *
 * The code in this file contains the header comments used to compile        *
 * mx12p_lib.c.  More comments can be found in libraries.doc                 *
 *                                                                           *
 *****************************************************************************/


#ifndef _MX12P_LIB
#define _MX12P_LIB 1

#include "psu120_lib.h"

#define _MX12P_LIB_VERSION  1.0

/* camera type, for CamParam.QSensorType */
#define SENSOR_FT12            12     /* FT12 sensor */
#define SENSOR_FT18            18     /* FT18 sensor */

/* camera mode, for CamParam.Mode  */
#define MODE_CONTINUOUS         3     /* continuous read-out */
#define MODE_TRIGGER_SINGLE     2     /* trigger mode, single shot */
#define MODE_TRIGGER_GATED      1     /* trigger mode, gated operation */
#define MODE_CONTROL            0     /* control mode */

/* video scan rates, for CamParam.Video */
#define BASED_50HZ              1     /* 50 Hz based standard */
#define BASED_60HZ              0     /* 60 Hz based standard */

/* interface types, for CamParam.Interface */
#define INTERFACE_TTL           1     /* single-ended TTL output */
#define INTERFACE_BAL           0     /* differential balanced output */

/* video gain, for CamParam.Gain and CamBuf.QGain */
#define GAIN_1X                 0     /* 1x gain (0 dB) */
#define GAIN_2X                 1     /* 2x gain (6 dB) */
#define GAIN_4X                 2     /* 4x gain (12 dB) */
#define GAIN_8X                 3     /* 8x gain (18 dB) */
#define GAIN_16X                4     /* 16x gain (24 dB) */
#define GAIN_32X                5     /* 32x gain (30 dB) */
#define GAIN_64X                6     /* 64x gain (36 dB) */

/* camera driver errors */
#define ERR_CAM_IPRT         -100     /* invalid port number used */
#define ERR_CAM_RESV         -101     /* port reserved or does not exist */
#define ERR_CAM_IHND         -102     /* invalid driver identifier used */
#define ERR_CAM_IPAR         -103     /* invalid value in TCamParameters */
#define ERR_CAM_INVR         -104     /* no MX12P NV-record found in NVRAM */

/* max number comm ports */
/* already defined in psu.h */


/* camera data */
struct TCamParameters_t {
  int Gamma;                /* gamma on/off */
  int Mirror;               /* mirroring on/off */
  int Sync;                 /* sync in CVBS on/off */
  int Interlace;            /* interlace on/off */
  int Black;                /* black shift on/off */
  int BlackFine;            /* fine black control on/off */
  int IntegrationTime;      /* integration time value */
  int Gain;                 /* video gain value */
  int BlackValue;           /* black level value */
  int Mode;                 /* camera mode value */
  int Standard;             /* video standard flag */
  int Interface;            /* digital interface type */
  int Option_1;             /* option 1 on/off */
  int Option_2;             /* option 2 on/off */
  int QIntegrationTime;     /* integration time in ms * 10 */
  int QBlackValue;          /* black level in % * 10 */
  int QGain;                /* gain level (1, 2, 4, enz) */
  int QPixelClock;          /* pixel clock in MHz */
  int QSensorType;          /* sensor type used in camera */
  int Invalidate;           /* force update of all camera parameters */
};

typedef struct TCamParameters_t TCamParameters;


/* function prototypes for mx12p */

extern int CamOpen(int);
extern int CamClose(int);
extern int CamTransfer(int, TCamParameters*);
extern int CamSaveAsDefault(int, TCamParameters*);
extern int CamLoadDefault(int, TCamParameters*);
extern int CamStartPoll(int);
extern int CamPoll(int);
extern int CamGetDeviceHandle(int);
/* new functions in this library */
extern void PrepContextTable(void);
extern int CamAttention(int);
extern int CamVersion(int,char*);

#endif  /* _MX12P_LIB */

